# Copyright (C) 2009  Xyne
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.


package Xyne::Common::Log;
use strict;
use warnings;

our $VERSION = '0.01';


sub new {
  my $proto = shift;
  my $class = ref($proto) || $proto;
  my $self  = {};
  bless ($self, $class);
  
  # set the log file path if given
  $self->{PATH} = shift @_ if (@_);
  
  # timestamp inclusion boolean
  $self->{ADD_TIMESTAMP} = 1;

  return $self;
}

sub DESTROY
{
  my ($self) = @_;
  $self->close_file_handle;
}

sub close_file_handle
{
  my ($self) = @_;
  close $self->{HANDLE} if defined($self->{HANDLE});
}

sub get_path
{
  my ($self) = @_;
  return $self->{PATH};
}

sub get_timestamp
{
  my ($self) = @_;
  my ($second,$minute,$hour,$day,$month,$year)=localtime(time);
  my $timestamp = sprintf("[%4d-%02d-%02d %02d:%02d:%02d] ",$year+1900,$month+1,$day,$hour,$minute,$second);
  return $timestamp;
}

sub log
{
  my ($self,@lines) = @_;
  $self->maybe_open_file_handle;
  if ($self->{ADD_TIMESTAMP})
  {
    my $timestamp = $self->get_timestamp;
    @lines = map {$timestamp.$_} @lines;
  }
  map {chomp} @lines;
  my $fh = $self->{HANDLE};
  print $fh "$_\n" foreach @lines;
}

sub maybe_open_file_handle
{
  my ($self) = @_;
  $self->open_file_handle if not defined($self->{HANDLE});
}

sub open_file_handle
{
  my ($self) = @_;
  my $path = $self->{PATH};
  open ($self->{HANDLE},'>>',$self->{PATH}) or die "error: unable to open $self->{PATH} ($!)";
}

sub set_path
{
  my ($self,$path) = @_;
  $self->close_file_handle;
  $self->{PATH} = $path;
}

# this may be used later
sub set_timestamp
{
  my ($self,$timestamp) = @_;
  $self->{TIMESTAMP} = $timestamp;
}

sub add_timestamp
{
  my ($self,$bool) = @_;
  $self->{ADD_TIMESTAMP} = $bool;
}

1;

__END__

=head1 NAME

Xyne::Common::Log - A simple log class.

=head1 SYNOPSIS

  use Xyne::Common::Log;

=head1 DESCRIPTION

A simple class to provide log objects for other
applications.

=head2 EXPORT

None by default.

=head1 AUTHOR

Xyne <lt>xyne at archlinux dot ca<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2009  Xyne

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

=cut